OC.L10N.register(
    "serverinfo",
    {
    "Users" : "Brukarare",
    "Groups" : "Grupper",
    "Links" : "Lenker",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikkje støtta!",
    "Press ⌘-C to copy." : "Trykk  ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "System" : "System",
    "Monitoring" : "Overvåker",
    "Size:" : "Storleik:",
    "Files:" : "Filar:",
    "Active users" : "Aktive brukarare",
    "Shares" : "Delingar",
    "Upload max size:" : "Maks opplastning storleik:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Eksternt monoitor verktøy",
    "Last minute" : "Siste minutt",
    "Memory info not available" : "Minne informasjon ikkje tilgjengleg",
    "Total" : "Totalt",
    "Current usage" : "Nåverende bruk",
    "Size" : "Storleik",
    "Hostname" : "Vertsnamn",
    "Status" : "Status",
    "Memory Limit:" : "Minne grense:",
    "Files" : "Filer",
    "Version" : "Utgåve",
    "Type" : "Type"
},
"nplurals=2; plural=(n != 1);");
